==> jaws_libp-4.0.1-py3-none-any.whl: jaws_libp/avro/schemas/__init__.py <==
"""
   AVRO schemas (.avsc data files) for JAWS.

    Schemas:

    * :download:`AlarmActivationUnion.avsc </../../src/jaws_libp/avro/schemas/AlarmActivationUnion.avsc>`
    * :download:`AlarmClass.avsc </../../src/jaws_libp/avro/schemas/AlarmClass.avsc>`
    * :download:`AlarmLocation.avsc </../../src/jaws_libp/avro/schemas/AlarmLocation.avsc>`
    * :download:`AlarmOverrideKey.avsc </../../src/jaws_libp/avro/schemas/AlarmOverrideKey.avsc>`
    * :download:`AlarmOverrideSet.avsc </../../src/jaws_libp/avro/schemas/AlarmOverrideSet.avsc>`
    * :download:`AlarmOverrideUnion.avsc </../../src/jaws_libp/avro/schemas/AlarmOverrideUnion.avsc>`
    * :download:`AlarmPriority.avsc </../../src/jaws_libp/avro/schemas/AlarmPriority.avsc>`
    * :download:`AlarmInstance.avsc </../../src/jaws_libp/avro/schemas/AlarmInstance.avsc>`
    * :download:`AlarmState.avsc </../../src/jaws_libp/avro/schemas/AlarmState.avsc>`
    * :download:`DisabledOverride.avsc </../../src/jaws_libp/avro/schemas/DisabledOverride.avsc>`
    * :download:`EffectiveActivation.avsc </../../src/jaws_libp/avro/schemas/EffectiveActivation.avsc>`
    * :download:`EffectiveAlarm.avsc </../../src/jaws_libp/avro/schemas/EffectiveAlarm.avsc>`
    * :download:`EffectiveRegistration.avsc </../../src/jaws_libp/avro/schemas/EffectiveRegistration.avsc>`
    * :download:`FilteredOverride.avsc </../../src/jaws_libp/avro/schemas/FilteredOverride.avsc>`
    * :download:`IntermediateMonolog.avsc </../../src/jaws_libp/avro/schemas/IntermediateMonolog.avsc>`
    * :download:`LatchedOverride.avsc </../../src/jaws_libp/avro/schemas/LatchedOverride.avsc>`
    * :download:`MaskedOverride.avsc </../../src/jaws_libp/avro/schemas/MaskedOverride.avsc>`
    * :download:`OffDelayedOverride.avsc </../../src/jaws_libp/avro/schemas/OffDelayedOverride.avsc>`
    * :download:`OnDelayedOverride.avsc </../../src/jaws_libp/avro/schemas/OnDelayedOverride.avsc>`
    * :download:`OverrideList.avsc </../../src/jaws_libp/avro/schemas/OverrideList.avsc>`
    * :download:`ProcessorTransitions.avsc </../../src/jaws_libp/avro/schemas/ProcessorTransitions.avsc>`
    * :download:`ShelvedOverride.avsc </../../src/jaws_libp/avro/schemas/ShelvedOverride.avsc>`

    `View Schemas on GitHub <https://github.com/JeffersonLab/jaws-libp/tree/main/src/jaws_libp/avro/schemas>`_
"""

==> jaws_libp-4.4.0-py3-none-any.whl: jaws_libp/avro/schemas/__init__.py <==
"""
   AVRO schemas (.avsc data files) for JAWS.

    Schemas:

    * :download:`AlarmActivationUnion.avsc </../../src/jaws_libp/avro/schemas/AlarmActivationUnion.avsc>`
    * :download:`AlarmClass.avsc </../../src/jaws_libp/avro/schemas/AlarmClass.avsc>`
    * :download:`AlarmLocation.avsc </../../src/jaws_libp/avro/schemas/AlarmLocation.avsc>`
    * :download:`AlarmOverrideKey.avsc </../../src/jaws_libp/avro/schemas/AlarmOverrideKey.avsc>`
    * :download:`AlarmOverrideSet.avsc </../../src/jaws_libp/avro/schemas/AlarmOverrideSet.avsc>`
    * :download:`AlarmOverrideUnion.avsc </../../src/jaws_libp/avro/schemas/AlarmOverrideUnion.avsc>`
    * :download:`AlarmInstance.avsc </../../src/jaws_libp/avro/schemas/AlarmInstance.avsc>`
    * :download:`AlarmState.avsc </../../src/jaws_libp/avro/schemas/AlarmState.avsc>`
    * :download:`DisabledOverride.avsc </../../src/jaws_libp/avro/schemas/DisabledOverride.avsc>`
    * :download:`EffectiveNotification.avsc </../../src/jaws_libp/avro/schemas/EffectiveNotification.avsc>`
    * :download:`EffectiveAlarm.avsc </../../src/jaws_libp/avro/schemas/EffectiveAlarm.avsc>`
    * :download:`EffectiveRegistration.avsc </../../src/jaws_libp/avro/schemas/EffectiveRegistration.avsc>`
    * :download:`FilteredOverride.avsc </../../src/jaws_libp/avro/schemas/FilteredOverride.avsc>`
    * :download:`IntermediateMonolog.avsc </../../src/jaws_libp/avro/schemas/IntermediateMonolog.avsc>`
    * :download:`LatchedOverride.avsc </../../src/jaws_libp/avro/schemas/LatchedOverride.avsc>`
    * :download:`MaskedOverride.avsc </../../src/jaws_libp/avro/schemas/MaskedOverride.avsc>`
    * :download:`OffDelayedOverride.avsc </../../src/jaws_libp/avro/schemas/OffDelayedOverride.avsc>`
    * :download:`OnDelayedOverride.avsc </../../src/jaws_libp/avro/schemas/OnDelayedOverride.avsc>`
    * :download:`OverrideList.avsc </../../src/jaws_libp/avro/schemas/OverrideList.avsc>`
    * :download:`ProcessorTransitions.avsc </../../src/jaws_libp/avro/schemas/ProcessorTransitions.avsc>`
    * :download:`ShelvedOverride.avsc </../../src/jaws_libp/avro/schemas/ShelvedOverride.avsc>`

    `View Schemas on GitHub <https://github.com/JeffersonLab/jaws-libp/tree/main/src/jaws_libp/avro/schemas>`_
"""
